@@ -210,6 +210,29 @@ class CdwchClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCNInstances(self, request):
+        """获取云原生实例列表
+
+        :param request: Request instance for DescribeCNInstances.
+        :type request: :class:`tencentcloud.cdwch.v20200915.models.DescribeCNInstancesRequest`
+        :rtype: :class:`tencentcloud.cdwch.v20200915.models.DescribeCNInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCNInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCNInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCkSqlApis(self, request):
         """查询集群用户、集群表，数据库等相关信息
 
@@ -325,6 +348,29 @@ class CdwchClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeInstanceNodes(self, request):
+        """获取实例节点信息列表
+
+        :param request: Request instance for DescribeInstanceNodes.
+        :type request: :class:`tencentcloud.cdwch.v20200915.models.DescribeInstanceNodesRequest`
+        :rtype: :class:`tencentcloud.cdwch.v20200915.models.DescribeInstanceNodesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstanceNodes", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstanceNodesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInstanceShards(self, request):
         """获取实例shard信息列表
 
@@ -578,6 +624,29 @@ class CdwchClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ScaleCNOutUpInstance(self, request):
+        """open-api接口提供弹性伸缩云原生集群能力
+
+        :param request: Request instance for ScaleCNOutUpInstance.
+        :type request: :class:`tencentcloud.cdwch.v20200915.models.ScaleCNOutUpInstanceRequest`
+        :rtype: :class:`tencentcloud.cdwch.v20200915.models.ScaleCNOutUpInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ScaleCNOutUpInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.ScaleCNOutUpInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ScaleOutInstance(self, request):
         """调整clickhouse节点数量
 
